from django.core.exceptions import ValidationError
from django import forms
from django.shortcuts import render
from django.http import HttpResponse, HttpResponseBadRequest, HttpResponseNotAllowed, HttpResponseNotFound
from django.shortcuts import redirect
from django.contrib.auth.decorators import login_required
from warpauth.ldap_connector import LDAPConnector
from warpauth.models import LdapUser, LdapUserForm
from warpauth.util import *
import logging

##
# http://www.python-ldap.org/doc/html/ldap.html#ldap.LDAPObject
# ToDo: first- and lastname, email, public?
##


def setUserObject(request):
    pages['ldap_groups'] = request.user.ldap_user.group_names
    pages['ldap_user_form'] = LdapUserForm(instance=LdapUser.objects.get(uid=str(request.user)))        
 
def clear_error_messages():
    pages["error_info"] = ""
    pages["success_info"] = False
    pages["error_passwd"] = ""
    pages["success_passwd"] = False
    pages["selected_tab"]=""
    
@login_required(login_url='/login/', redirect_field_name=None)
def index(request):
    clear_error_messages()
    pages['ldap_groups'] = request.user.ldap_user.group_names
    pages['ldap_user_form'] = LdapUserForm(instance=LdapUser.objects.get(uid=str(request.user)))
    return HttpResponse(render(request, 'warpauth/profile.html', pages))


@login_required(login_url='/login/', redirect_field_name=None)
def change_information(request):
    clear_error_messages()
    setUserObject(request)
    if request.method != 'POST':
        return redirect("/profile")

    user = LdapUser.objects.get(uid=str(request.user))
    first_name = request.POST["first_name"]
    last_name = request.POST["last_name"]
    email = request.POST["email"]
    card_id = request.POST["card_id"]
    f = forms.EmailField()
    try:
        f.clean(email)
    except ValidationError as e:
        pages["error_info"] = "Invalid Email"
        return HttpResponse(render(request, 'warpauth/profile.html', pages))
    cn = first_name + " " + last_name
    cn = cn.strip()
    if first_name == "":
        first_name = "None"
    if last_name == "":
        last_name = "None"
    if cn == "":
        cn = "None"

    user.first_name = first_name
    user.last_name = last_name
    user.cn = cn
    user.email = email
    user.card_id=card_id
    user.save()

    pages["success_info"] = True
    setUserObject(request)
    return HttpResponse(render(request, 'warpauth/profile.html', pages))


@login_required(login_url='/login/', redirect_field_name=None)
def change_password(request):
    clear_error_messages()
    pages["selected_tab"]="#change_passwd"
    if request.method != 'POST':
        return redirect("/profile")
    print("old_pw" == "")
    if request.POST["old_pw"] == "" or request.POST["new_pw"]  == "" or request.POST["new_pw_confirm"] == "":
        pages["error_passwd"] = "Please fill in all fields"
    elif request.POST["new_pw"] != request.POST["new_pw_confirm"]:
        pages["error_passwd"] = "Password confirmation did not match"
    else:
        ldap_connector = LDAPConnector()
        ret = ldap_connector.change_user_password(request.user.ldap_user.dn, request.POST["old_pw"], request.POST["new_pw"])
        if ret == -1:
            pages["error_passwd"] = "Old password did not match"
        else:
            send_password_change_notification(LdapUser.objects.get(uid=str(request.user)))
            pages["success_passwd"] = True
    pages['ldap_groups'] = request.user.ldap_user.group_names
    pages['ldap_user_form'] = LdapUserForm(instance=LdapUser.objects.get(uid=str(request.user)))        
    return HttpResponse(render(request, 'warpauth/profile.html', pages))
    
